==> sca-patterns-sle12-1.5.5.tar.gz: sca-patterns-sle12-1.5.5/patterns/SLE/sle12sp5/bind_SUSE-SU-2021_1468-1_12.5.py <==
#!/usr/bin/python3
#
# Title:       Important Security Announcement for bind SUSE-SU-2021:1468-1
# Description: Security fixes for SUSE Linux Enterprise 12 SP5
# Source:      Security Announcement Parser v1.6.1
# Modified:    2021 Jun 01
#
##############################################################################
# Copyright (C) 2021 SUSE LLC
##############################################################################
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.
#
#  Authors/Contributors:
#   Jason Record <jason.record@suse.com>
#
##############################################################################

import os
import Core
import SUSE

META_CLASS = "Security"
META_CATEGORY = "SLE"
META_COMPONENT = "bind"
PATTERN_ID = os.path.basename(__file__)
PRIMARY_LINK = "META_LINK_Security"
OVERALL = Core.TEMP
OVERALL_INFO = "NOT SET"
OTHER_LINKS = "META_LINK_Security=https://lists.suse.com/pipermail/sle-security-updates/2021-May/008725.html"
Core.init(META_CLASS, META_CATEGORY, META_COMPONENT, PATTERN_ID, PRIMARY_LINK, OVERALL, OVERALL_INFO, OTHER_LINKS)

LTSS = False
NAME = 'bind'
MAIN = ''
SEVERITY = 'Important'
TAG = 'SUSE-SU-2021:1468-1'
PACKAGES = {}
SERVER = SUSE.getHostInfo()

if ( SERVER['DistroVersion'] == 12):
	if ( SERVER['DistroPatchLevel'] == 5 ):
		PACKAGES = {
			'bind': '9.11.22-3.34.1',
			'bind-chrootenv': '9.11.22-3.34.1',
			'bind-debuginfo': '9.11.22-3.34.1',
			'bind-debugsource': '9.11.22-3.34.1',
			'bind-doc': '9.11.22-3.34.1',
			'bind-utils': '9.11.22-3.34.1',
			'bind-utils-debuginfo': '9.11.22-3.34.1',
			'libbind9-161': '9.11.22-3.34.1',
			'libbind9-161-debuginfo': '9.11.22-3.34.1',
			'libdns1110': '9.11.22-3.34.1',
			'libdns1110-debuginfo': '9.11.22-3.34.1',
			'libirs161': '9.11.22-3.34.1',
			'libirs161-debuginfo': '9.11.22-3.34.1',
			'libisc1107': '9.11.22-3.34.1',
			'libisc1107-32bit': '9.11.22-3.34.1',
			'libisc1107-debuginfo': '9.11.22-3.34.1',
			'libisc1107-debuginfo-32bit': '9.11.22-3.34.1',
			'libisccc161': '9.11.22-3.34.1',
			'libisccc161-debuginfo': '9.11.22-3.34.1',
			'libisccfg163': '9.11.22-3.34.1',
			'libisccfg163-debuginfo': '9.11.22-3.34.1',
			'liblwres161': '9.11.22-3.34.1',
			'liblwres161-debuginfo': '9.11.22-3.34.1',
			'python-bind': '9.11.22-3.34.1',
		}
		SUSE.securityAnnouncementPackageCheck(NAME, MAIN, LTSS, SEVERITY, TAG, PACKAGES)
	else:
		Core.updateStatus(Core.ERROR, "ERROR: " + NAME + " Security Announcement: Outside the service pack scope")
else:
	Core.updateStatus(Core.ERROR, "ERROR: " + NAME + " Security Announcement: Outside the distribution scope")
Core.printPatternResults()

==> sca-patterns-sle12-1.5.7.tar.gz: sca-patterns-sle12-1.5.7/patterns/SLE/sle12sp5/bind_SUSE-SU-2021_0503-1_12.5.py <==
#!/usr/bin/python3
#
# Title:       Important Security Announcement for bind SUSE-SU-2021:0503-1
# Description: Security fixes for SUSE Linux Enterprise 12 SP5
# Source:      Security Announcement Parser v1.6.1
# Modified:    2021 Mar 03
#
##############################################################################
# Copyright (C) 2021 SUSE LLC
##############################################################################
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.
#
#  Authors/Contributors:
#   Jason Record <jason.record@suse.com>
#
##############################################################################

import os
import Core
import SUSE

META_CLASS = "Security"
META_CATEGORY = "SLE"
META_COMPONENT = "bind"
PATTERN_ID = os.path.basename(__file__)
PRIMARY_LINK = "META_LINK_Security"
OVERALL = Core.TEMP
OVERALL_INFO = "NOT SET"
OTHER_LINKS = "META_LINK_Security=https://lists.suse.com/pipermail/sle-security-updates/2021-February/008343.html"
Core.init(META_CLASS, META_CATEGORY, META_COMPONENT, PATTERN_ID, PRIMARY_LINK, OVERALL, OVERALL_INFO, OTHER_LINKS)

LTSS = False
NAME = 'bind'
MAIN = ''
SEVERITY = 'Important'
TAG = 'SUSE-SU-2021:0503-1'
PACKAGES = {}
SERVER = SUSE.getHostInfo()

if ( SERVER['DistroVersion'] == 12):
	if ( SERVER['DistroPatchLevel'] == 5 ):
		PACKAGES = {
			'bind': '9.11.22-3.29.1',
			'bind-chrootenv': '9.11.22-3.29.1',
			'bind-debuginfo': '9.11.22-3.29.1',
			'bind-debugsource': '9.11.22-3.29.1',
			'bind-doc': '9.11.22-3.29.1',
			'bind-utils': '9.11.22-3.29.1',
			'bind-utils-debuginfo': '9.11.22-3.29.1',
			'libbind9-161': '9.11.22-3.29.1',
			'libbind9-161-debuginfo': '9.11.22-3.29.1',
			'libdns1110': '9.11.22-3.29.1',
			'libdns1110-debuginfo': '9.11.22-3.29.1',
			'libirs161': '9.11.22-3.29.1',
			'libirs161-debuginfo': '9.11.22-3.29.1',
			'libisc1107': '9.11.22-3.29.1',
			'libisc1107-32bit': '9.11.22-3.29.1',
			'libisc1107-debuginfo': '9.11.22-3.29.1',
			'libisc1107-debuginfo-32bit': '9.11.22-3.29.1',
			'libisccc161': '9.11.22-3.29.1',
			'libisccc161-debuginfo': '9.11.22-3.29.1',
			'libisccfg163': '9.11.22-3.29.1',
			'libisccfg163-debuginfo': '9.11.22-3.29.1',
			'liblwres161': '9.11.22-3.29.1',
			'liblwres161-debuginfo': '9.11.22-3.29.1',
			'python-bind': '9.11.22-3.29.1',
		}
		SUSE.securityAnnouncementPackageCheck(NAME, MAIN, LTSS, SEVERITY, TAG, PACKAGES)
	else:
		Core.updateStatus(Core.ERROR, "ERROR: " + NAME + " Security Announcement: Outside the service pack scope")
else:
	Core.updateStatus(Core.ERROR, "ERROR: " + NAME + " Security Announcement: Outside the distribution scope")
Core.printPatternResults()
